clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear


********************************
// SECTION 4.1: MENU PREFERENCES
********************************

// Basic descriptive statistics 

su menuchoice1 menuchoice2 menuchoice3


// OA-A.1 Testing for order effects - statistics reported at the bottom of p.3

gen top_0 = (menuchoice1==1)
ttest top_0, by(dierankorder)

ttest menuchoice1, by(dierankorder) // 1.62 vs. 1.41 - p = 0.103
ttest menuchoice2, by(dierankorder) // 2.41 vs. 2.51 - p = 0.434
ttest menuchoice3, by(dierankorder) // 1.56 vs. 1.65 - p = 0.434


// OA-A.1 FIGURE 1(a) 

histogram menuchoice1 if dierankorder==1, discrete addlabels bcolor(navy) addlabopts(yvarformat(%4.0f))  percent gap(40) xlabel(1(1)3) ylabel(0(10)70, nogrid) xtitle("rank number") ytitle("% of subjects")  title("menu {0}")  graphregion(color(white)) saving(g1, replace) nodraw 
histogram menuchoice2 if dierankorder==1, discrete addlabels bcolor(navy) addlabopts(yvarformat(%4.0f))  percent gap(40) xlabel(1(1)3)  ylabel(0(10)70, nogrid) xtitle("rank number") ytitle(" ") title("menu {1}")  graphregion(color(white)) saving(g2, replace) nodraw 
histogram menuchoice3 if dierankorder==1, discrete addlabels bcolor(navy) addlabopts(yvarformat(%4.0f))  percent gap(40) xlabel(1(1)3) ylabel(0(10)70, nogrid) xtitle("rank number") ytitle (" ") title("menu {0,1}")  graphregion(color(white)) saving(g3, replace) nodraw
graph combine g1.gph g2.gph g3.gph, col(3) graphregion(color(white)) saving(OA_Fig1a, replace)
graph export "OA_Fig1a.pdf", replace 
graph export "OA_Fig1a.eps", replace


// OA-A.1 FiGURE 1(b)

histogram menuchoice1 if dierankorder==2, discrete addlabels bcolor(navy) addlabopts(yvarformat(%4.0f))  percent gap(40) xlabel(1(1)3) ylabel(0(10)70, nogrid) xtitle("rank number") ytitle("% of subjects")  title("menu {0}")  graphregion(color(white)) saving(g1, replace) nodraw 
histogram menuchoice2 if dierankorder==2, discrete addlabels bcolor(navy) addlabopts(yvarformat(%4.0f))  percent gap(40) xlabel(1(1)3)  ylabel(0(10)70, nogrid) xtitle("rank number") ytitle(" ") title("menu {1}")  graphregion(color(white)) saving(g2, replace) nodraw 
histogram menuchoice3 if dierankorder==2, discrete addlabels bcolor(navy) addlabopts(yvarformat(%4.0f))  percent gap(40) xlabel(1(1)3) ylabel(0(10)70, nogrid) xtitle("rank number") ytitle (" ") title("menu {0,1}")  graphregion(color(white)) saving(g3, replace) nodraw
graph combine g1.gph g2.gph g3.gph, col(3) graphregion(color(white)) saving(OA_Fig1b, replace)
graph export "OA_Fig1b.pdf", replace 
graph export "OA_Fig1b.eps", replace


***********************
// Coding of menu types
***********************
// menutype variable:

/* type 1: (1,2,3) 
   type 2: (1,3,2)
   type 3: (2,1,3)
   type 4: (3,1,2)
   type 5: (2,3,1)
   type 6: (3,2,1)
   type 7: (1,1,2)
   type 8: (1,2,1)
   type 9: (2,1,1)
   type 10: (1,2,2)
   type 11: (2,1,2)
   type 12: (2,2,1)
   type 13: (1,1,1)*/
***********************


*******************************************
// Subsection 4.1.1: Initial Rank Orderings
*******************************************

// TABLE 1: Main Preference Orderings p.15 with p-values from binomial tests reported in last column

tab menutype 

gen ssb_0 = 0
replace ssb_0 = 1 if menutype ==2
bitest ssb_0 = 1/13 // p <0.001

gen ssb_1 = 0
replace ssb_1 = 1 if menutype ==4
bitest ssb_1 = 1/13 // p=0.171

gen flex_0 = 0
replace flex_0 = 1 if menutype==5
bitest flex_0 = 1/13 // p<0.001

gen flex_1 = 0
replace flex_1 = 1 if menutype==6
bitest flex_1 = 1/13 // p=1.000

gen flex_eq = 0
replace flex_eq = 1 if menutype==12
bitest flex_eq = 1/13 // p=0.605

gen guilt = 0
replace guilt = 1 if menutype == 1
bitest guilt = 1/13 // p=0.863

gen std = 0 
replace std = 1 if menutype == 8
bitest std = 1/13 // p=0.494

gen bd = 0
replace bd = 1 if menutype == 10
bitest bd = 1/13 // 0.026


**********************************************************************
// Subsection 4.1.2: Refinement of menu rankings through WTP decisions
**********************************************************************

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear


// Comparison of WTP for time vs. money

// OA-A.1 FIGURE 2

reshape long wtp1_choice wtp2_choice tc1_choice tc2_choice wtp tc, i(id) j(option)

replace tc = tc/60

graph bar (mean) wtp1_choice, over(wtp) title("$ WTP for 1st vs. 2nd choice") ytitle("") ylab(0(0.2)1, nogrid) graphregion(color(white)) saving(f1, replace) nodraw
graph bar (mean) wtp2_choice, over(wtp) title("$ WTP for 2nd vs. 3rd choice") ytitle("") ylab(0(0.2)1, nogrid) graphregion(color(white)) saving(f2, replace) nodraw
graph bar (mean) tc1_choice, over(tc) title("Time WTP for 1st vs. 2nd choice") ytitle("") ylab(0(0.2)1, nogrid) graphregion(color(white)) saving(f3, replace) nodraw
graph bar (mean) tc2_choice, over(tc) title("Time WTP for 2nd vs. 3rd choice") ytitle("") ylab(0(0.2)1, nogrid) graphregion(color(white)) saving(f4, replace) nodraw  

graph combine f1.gph f2.gph f3.gph f4.gph, graphregion(color(white)) saving(OA_Fig2, replace)
graph export "OA_Fig2.pdf", replace 
graph export "OA_Fig2.eps", replace


// Computation of converted WTP as described in the footnote of TABLE 2 p.17


clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

replace ptime1 = ptime1/60
replace ptime2 = ptime2/60

gen norm_time1 = 0 if ptime1 !=.
replace norm_time1 = 0.01 if ptime1 == 1
replace norm_time1 = 0.5 if ptime1 == 10
replace norm_time1 = 0.01 +  0.5*(ptime1-1)/(10-1) if ptime1 !=0 & ptime1 !=10 & ptime1 !=.

gen norm_time2 = 0 if ptime2 !=.
replace norm_time2 = 0.01 if ptime2 == 1
replace norm_time2 = 0.5 if ptime2 == 10
replace norm_time2 = 0.01 +  0.5*(ptime2-1)/(10-1) if ptime2 !=0 & ptime2 !=10 & ptime2 !=.

rename strict_12 strict1
rename strict_23 strict2

rename wtp1_total wtp_total1
rename wtp2_total wtp_total2
rename tc1_total tc_total1
rename tc2_total tc_total2

reshape long money norm_time wtp_total tc_total indiff strict, i(id) j(comparison_rank)

gen wtp_replace = money 
replace wtp_replace = norm_time if money ==.

gen total_mpl = wtp_total
replace total_mpl = tc_total if money==.

gen strict_wtp = 0
replace strict_wtp = 1 if wtp_replace >0

gen money_condition = 0
replace money_condition = 1 if ptime1 ==.

gen time_condition = 0
replace time_condition = 1 if ptime1 !=.


// F-Stat results reported on p.16 of the main text 

reg strict_wtp money_condition time_condition, nocons cluster(id)
test money_condition == time_condition

reg total_mpl money_condition time_condition, nocons cluster(id)
test money_condition == time_condition

// Results from Kolmogorov-Smirnov tests reported on p.6 of OA-A1

ksmirnov total_mpl if comparison_rank==1, by(money_condition)
ksmirnov total_mpl if comparison_rank==2, by(money_condition)


/* TABLE 2: Mean WTP and % with WTP>0 by menutype and comparison rank
How to obtain the first line (all 4 columns in order): */

ta strict_wtp if menutype==2 & comparison_rank==1
su wtp_replace if menutype==2 & comparison_rank==1

ta strict_wtp if menutype==2 & comparison_rank==2
su wtp_replace if menutype==2 & comparison_rank==2

// t-tests reported at the bottom of page 16

ttest wtp_replace if comparison_rank==1, by(strict)
ttest wtp_replace if comparison_rank==2, by(strict)


// TABLE 3: Alternative classification accounting for WTP choices with p-values from binomial tests reported in last column

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

tab alt_ranking2

gen ssb_0_alt = 0
replace ssb_0_alt = 1 if  alt_ranking2==2
bitest ssb_0_alt = 1/13 // p = 0.000

gen ssb_1_alt = 0
replace ssb_1_alt = 1 if alt_ranking2 ==4
bitest ssb_1_alt = 1/13 // p=0.084

gen flex_0_alt = 0
replace flex_0_alt = 1 if alt_ranking2==5
bitest flex_0_alt = 1/13 // p=0.226

gen flex_1_alt = 0
replace flex_1_alt = 1 if alt_ranking2==6
bitest flex_1_alt = 1/13 // p=0.605

gen guilt_alt = 0
replace guilt_alt = 1 if alt_ranking2 == 1
bitest guilt_alt = 1/13 // p=0.732

gen std_alt = 0 
replace std_alt = 1 if alt_ranking2== 8
bitest std_alt = 1/13 // p=0.000

gen ind = 0
replace ind = 1 if alt_ranking2==13
bitest ind = 1/13 // p=0.496

gen bd_alt = 0
replace bd_alt = 1 if alt_ranking2==10
bitest bd_alt = 1/13 // p=0.026


ta alt_ranking2 if inconsistent1==0 // OA-A.2 Table 2

bitest ssb_0_alt = 1/13 if inconsistent1==0
bitest ssb_1_alt = 1/13 if inconsistent1==0
bitest flex_0_alt = 1/13 if inconsistent1==0
bitest flex_1_alt = 1/13 if inconsistent1==0
bitest std_alt = 1/13 if inconsistent1==0
bitest guilt_alt = 1/13 if inconsistent1==0
bitest ind = 1/13 if inconsistent1==0

ta alt_ranking2 if inconsistent2==0 // OA-A.2 Table 3

bitest ssb_0_alt = 1/13 if inconsistent2==0
bitest ssb_1_alt = 1/13 if inconsistent2==0
bitest flex_0_alt = 1/13 if inconsistent2==0
bitest flex_1_alt = 1/13 if inconsistent2==0
bitest std_alt = 1/13 if inconsistent2==0
bitest guilt_alt = 1/13 if inconsistent2==0

gen lb_ssb0 = (menutype==2 & alt_ranking2==2)
bitest lb_ssb0 = 1/13

**************************************************************************************
// Subsection 4.1.3: Link between menu preferences and beliefs about Period 2 behavior
**************************************************************************************

// FIGURE 3 Appendix of main text p.35

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

collapse (mean) belieflearn, by(owninterest)

replace belieflearn = round(belieflearn, 0.01)

twoway scatter belieflearn owninterest, mlabel(belieflearn) mlabposition(12) connect(ascending) xtitle("belief about oneself") ///
mlabgap(1.5) ytitle("mean belief about other") ylab(0(0.2)1, nogrid) graphregion(color(white)) ///
xlabel(1 "very unlikely" 2 "quite unlikely" 3 "unsure" 4 "quite likely" 5 "very likely", labsize(2.5)) saving(main_Fig3, replace)
graph export "main_Fig3.pdf", replace 
graph export "main_Fig3.eps", replace

// Belief tables and reported statistics 

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

gen ownbelief = 0 
replace ownbelief = . if owninterest ==3
replace ownbelief = 1 if owninterest >3

gen ownbelief_alt = 0 
replace ownbelief_alt = 1 if owninterest ==3 & belieflearn==1
replace ownbelief_alt = 1 if owninterest >3

// Level of consistency as mentioned at the top of page 19

gen consist_belief = 0
replace consist_belief = 1 if ownbelief ==1 & belieflearn==1 | ownbelief ==0 & belieflearn==0
replace consist_belief =. if ownbelief ==. // 91/102  (89.2%)

// TABLE 8 Appendix of main text p.35

tab belieflearn ownbelief, col row exact


// TABLE 4: Relationship between menu preferences and beliefs about Period 2 choices 
// How to obtain the first line:

ta belieflearn if menutype == 2
ta belieflearn if alt_ranking2 == 2

ta ownbelief_alt if menutype == 2
ta ownbelief_alt if alt_ranking2 == 2


// Predictive power of menu preferences: relationship with beliefs and ex post choice
// OA-E.1 TABLE 15 and comments p.20 & 21 of main text

// Restrictions of NPR

gen NPR_0 = 0 // {0} > {1} according to initial classification based on rank
replace NPR_0 = 1 if menutype ==1 | menutype ==2 | menutype == 5 | menutype ==8 | menutype == 10

gen NPR_1 = 0 // {1} > {0} according to initial classification based on rank
replace NPR_1 = 1 if menutype ==3 | menutype ==4 | menutype == 6 | menutype ==9 | menutype == 11

gen NPR_0_alt = 0 // {0} > {1} according to initial classification based on WTP
replace NPR_0_alt = 1 if alt_ranking2 ==1 | alt_ranking2 ==2 | alt_ranking2 == 5 | alt_ranking2 ==8 | alt_ranking2 == 10

gen NPR_1_alt = 0 // {1} > {0} according to initial classification based on WTP
replace NPR_1_alt = 1 if alt_ranking2 ==3 | alt_ranking2 ==4 | alt_ranking2 == 6 | alt_ranking2 ==9 | alt_ranking2 == 11


// Restrictions of S

gen S0 = 0 // {0,1} > {1} according to initial classification based on rank
replace S0 = 1 if menutype ==2 | menutype==5 | menutype== 6 | menutype==8 | menutype== 12 

gen S1 = 0 // {0,1} > {0} according to initial classification based on rank
replace S1 = 1 if menutype ==4 | menutype==5 | menutype== 6 | menutype==9 | menutype== 12 

gen S0_alt = 0 // {0,1} > {1} according to initial classification based on WTP
replace S0_alt = 1 if alt_ranking2 ==2 | alt_ranking2 ==5 | alt_ranking2 == 6 | alt_ranking2 ==8 | alt_ranking2 == 12

gen S1_alt = 0 // {0,1} > {0} according to initial classification based on WTP
replace S1_alt = 1 if alt_ranking2 ==4 | alt_ranking2 ==5 | alt_ranking2 == 6 | alt_ranking2 ==9 | alt_ranking2 == 12


// OA-E.1 Regressions TABLE 15

// Panel A
reg belieflearn S0 S1 
reg belieflearn NPR_0 NPR_1 
reg belieflearn S0 S1 NPR_0 NPR_1  

reg belieflearn S0_alt S1_alt
reg belieflearn NPR_0_alt NPR_1_alt
reg belieflearn S0_alt S1_alt NPR_0_alt NPR_1_alt 

// Panel B
reg ownbelief_alt S0 S1 
reg ownbelief_alt NPR_0 NPR_1 
reg ownbelief_alt S0 S1 NPR_0 NPR_1  

reg ownbelief_alt S0_alt S1_alt
reg ownbelief_alt NPR_0_alt NPR_1_alt
reg ownbelief_alt S0_alt S1_alt NPR_0_alt NPR_1_alt 

// Panel C
reg learned S0 S1 if menuselection==3
reg learned NPR_0 NPR_1 if menuselection==3
reg learned S0 S1 NPR_0 NPR_1 if menuselection==3

reg learned S0_alt S1_alt if menuselection==3
reg learned NPR_0_alt NPR_1_alt if menuselection==3
reg learned S0_alt S1_alt NPR_0_alt NPR_1_alt if menuselection==3



******************************************************************
// 4.2.1 Link between menu preferences and actual Period 2 choices
******************************************************************

replace menutype = . if menutype == 7 | menutype == 9 | menutype == 10 | menutype == 11 | menutype == 13
replace alt_ranking2 = . if alt_ranking2 ==3 | alt_ranking2== 7 | alt_ranking2== 9 | alt_ranking2== 10 | alt_ranking2== 11 | alt_ranking2==12


// FIGURE 2 main text - Incentivized beliefs 
// N.b.: frequencies in fraction format for bar labels were modified by hand [ta learned if menutype = n & menuselection==3]

graph bar (mean) belieflearn learned if menuselection==3, over(menutype, relabel(1 "{it:{stSerif:GUILT}}" 2 "{it:{stSerif:SSB_{subscript:0}}}" 3 "{it:{stSerif:SSB_{subscript:1}}}" 4 "{it:{stSerif:FLEX_{subscript:0}}}" 5 "{it:{stSerif:FLEX_{subscript:1}}}" 6 "{it:{stSerif:STD_{subscript:0}}}" 7 "{it:{stSerif:FLEX_{subscript:0v1}}}" ))  ///
ytitle("fraction of subjects") yvaroptions(relabel(1 "expected Option 1 (reading)" 2 "chose Option 1 (reading)")) title("classification based on rank ordering") ///
bar(1, bcolor(navy)) bar(2, bcolor(red*0.4) lcolor(red*0.9))  ///
ylab(0(0.2)1, nogrid) blabel(bar, position(outside) format(%9.2f)) graphregion(color(white)) saving(f1, replace) nodraw

graph bar (mean) belieflearn learned if menuselection==3, over(alt_ranking2, relabel(1 "{it:{stSerif:GUILT}}" 2 "{it:{stSerif:SSB_{subscript:0}}}" 3 "{it:{stSerif:SSB_{subscript:1}}}" 4 "{it:{stSerif:FLEX_{subscript:0}}}" 5 "{it:{stSerif:FLEX_{subscript:1}}}" 6 "{it:{stSerif:STD_{subscript:0}}}" 7 "{it:{stSerif:IND}}" )) ///
bar(1, bcolor(navy)) bar(2, bcolor(red*0.4) lcolor(red*0.9))  ///
ytitle("fraction of subjects") ylab(0(0.2)1, nogrid) title("classification based on {it:{stSerif:WTP}}")  blabel(bar, position(outside) format(%9.2f)) graphregion(color(white)) saving(f2, replace) nodraw
grc1leg f1.gph f2.gph, col(1) graphregion(color(white)) saving(main_Fig2, replace)

graph export "main_Fig2.pdf", replace 
graph export "main_Fig2.eps", replace

// OA-E.1 FIGURE 19 - Unincentivized beliefs  
// N.b.: frequencies in fraction format for bar labels were modified by hand - obtained by typing [ta learned if menutype = n & menuselection==3]

replace learned = . if ownbelief ==.

graph bar (mean) ownbelief learned if menuselection==3, over(menutype, relabel(1 "{it:{stSerif:GUILT}}" 2 "{it:{stSerif:SSB_{subscript:0}}}" 3 "{it:{stSerif:SSB_{subscript:1}}}" 4 "{it:{stSerif:FLEX_{subscript:0}}}" 5 "{it:{stSerif:FLEX_{subscript:1}}}" 6 "{it:{stSerif:STD_{subscript:0}}}" 7 "{it:{stSerif:FLEX_{subscript:0v1}}}" ))  ///
ytitle("fraction of subjects") yvaroptions(relabel(1 "expected Option 1 (reading)" 2 "chose Option 1 (reading)")) title("classification based on rank ordering") ///
bar(1, bcolor(navy)) bar(2, bcolor(red*0.4) lcolor(red*0.9))  ///
ylab(0(0.2)1, nogrid) blabel(bar, position(outside) format(%9.2f)) graphregion(color(white)) saving(f1, replace) nodraw

graph bar (mean) ownbelief learned if menuselection==3, over(alt_ranking2, relabel(1 "{it:{stSerif:GUILT}}" 2 "{it:{stSerif:SSB_{subscript:0}}}" 3 "{it:{stSerif:SSB_{subscript:1}}}" 4 "{it:{stSerif:FLEX_{subscript:0}}}" 5 "{it:{stSerif:FLEX_{subscript:1}}}" 6 "{it:{stSerif:STD_{subscript:0}}}" 7 "{it:{stSerif:IND}}" )) ///
bar(1, bcolor(navy)) bar(2, bcolor(red*0.4) lcolor(red*0.9)) ///
ytitle("fraction of subjects") ylab(0(0.2)1, nogrid) title("classification based on {it:{stSerif:WTP}}")  blabel(bar, position(outside) format(%9.2f)) graphregion(color(white)) saving(f2, replace) nodraw
grc1leg f1.gph f2.gph, col(1) graphregion(color(white)) saving(OA_Fig19, replace)

graph export "OA_Fig19.pdf", replace 
graph export "OA_Fig19.eps", replace

// OA-E.1 FIGURE 20 - Inconsistencies between behavior and beliefs
// N.b.: frequencies in fraction format for bar labels were modified by hand [ta learned if menutype = n & menuselection==3]

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

gen ownbelief = 0 
replace ownbelief = . if owninterest ==3
replace ownbelief = 1 if owninterest >3

gen naive = 0
replace naive = 1 if (learned==1 & belieflearn==0) | (learned==0 & belieflearn==1)

gen naive_alt = 0
replace naive_alt = 1 if (learned==1 & ownbelief ==0) | (learned==0 & ownbelief ==1)
replace naive_alt = . if owninterest==3

replace menutype = . if menutype == 7 | menutype == 9 | menutype == 10 | menutype == 11 | menutype==13
graph bar (mean) naive naive_alt if menuselection==3, over(menutype, relabel(1 "{it:{stSerif:GUILT}}" 2 "{it:{stSerif:SSB_{subscript:0}}}" 3 "{it:{stSerif:SSB_{subscript:1}}}" 4 "{it:{stSerif:FLEX_{subscript:0}}}" 5 "{it:{stSerif:FLEX_{subscript:1}}}" 6 "{it:{stSerif:STD_{subscript:0}}}" 7 "{it:{stSerif:FLEX_{subscript:0v1}}}" )) ///
bar(1, bcolor(navy)) bar(2, bcolor(navy*0.4) lcolor(navy*0.9)) ///
yvaroptions(relabel(1 "incentivized belief measure" 2 "unincentivized belief measure")) title("classification based on rank ordering") ///
ylab(0(0.2)1, nogrid) graphregion(color(white))  blabel(bar, position(outside) format(%9.2f)) ytitle("") saving(g1, replace) nodraw

replace alt_ranking2 = . if alt_ranking2 ==3 | alt_ranking2== 7 | alt_ranking2== 9 | alt_ranking2== 10 | alt_ranking2== 11 | alt_ranking2==12
graph bar (mean) naive naive_alt if menuselection==3, over(alt_ranking2, relabel(1 "{it:{stSerif:GUILT}}" 2 "{it:{stSerif:SSB_{subscript:0}}}" 3 "{it:{stSerif:SSB_{subscript:1}}}" 4 "{it:{stSerif:FLEX_{subscript:0}}}" 5 "{it:{stSerif:FLEX_{subscript:1}}}" 6 "{it:{stSerif:STD_{subscript:0}}}" 7 "{it:{stSerif:IND}}" )) ///
bar(1, bcolor(navy)) bar(2, bcolor(navy*0.4) lcolor(navy*0.9)) ///
yvaroptions(relabel(1 "incentivized belief measure" 2 "unincentivized belief measure")) title("classification based on {it:{stSerif:WTP}}") ///
ylab(0(0.2)1, nogrid) graphregion(color(white)) blabel(bar, position(outside) format(%9.2f)) ytitle("") saving(g2, replace) nodraw

grc1leg g1.gph g2.gph, col(1) graphregion(color(white)) saving(OA_Fig20, replace)

graph export "OA_Fig20.pdf", replace 
graph export "OA_Fig20.eps", replace


// OA-E.1 TABLE 14

ta belieflearn learned if menuselection==3, row col chi2 // Panel A
ta ownbelief learned if menuselection==3, row col chi2 // Panel B


// OA-E.1 FIGURE 18(a) - Distribution of own beliefs by type  

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

// Using initial classification based on rank
gen mcat1 = 1 if menutype==2
replace mcat1 = 2 if menutype==4
replace mcat1 = 3 if menutype==5
replace mcat1 = 4 if menutype==6
replace mcat1 = 5 if menutype==8
replace mcat1 = 6 if menutype==1

capture label define mcat1 1 "{it:{stSerif:SSB_{subscript:0}}}" 2 "{it:{stSerif:SSB_{subscript:1}}}" ///
3 "{it:{stSerif:FLEX_{subscript:0}}}" 4 "{it:{stSerif:FLEX_{subscript:1}}}" 5 "{it:{stSerif:STD_{subscript:0}}}" 6 "{it:{stSerif:GUILT}}"
label val mcat1 mcat1

histogram owninterest, by(mcat1, note("") col(2) graphregion(color(white)) ) gap(40) percent discrete xlabel(1(1)5) ylabel( , nogrid)  ///
xlabel(1 "very unlikely" 2 "quite unlikely" 3 "unsure" 4 "quite likely" 5 "very likely", noticks alternate labsize(3))  ///
ytitle("% of subjects") bcolor(navy) xtitle("") plotregion(fcolor(gray) intensity(15)) 

graph export "OA_Fig18a.pdf", replace 
graph export "OA_Fig18a.eps", replace


// Using WTP classification
gen mcat2 = 1 if alt_ranking2==2
replace mcat2 = 2 if alt_ranking2==4
replace mcat2 = 3 if alt_ranking2==5
replace mcat2 = 4 if alt_ranking2==6
replace mcat2 = 5 if alt_ranking2==8
replace mcat2 = 6 if alt_ranking2==1

capture label define mcat2 1 "{it:{stSerif:SSB_{subscript:0}}}" 2 "{it:{stSerif:SSB_{subscript:1}}}" ///
3 "{it:{stSerif:FLEX_{subscript:0}}}" 4 "{it:{stSerif:FLEX_{subscript:1}}}" 5 "{it:{stSerif:STD_{subscript:0}}}" 6 "{it:{stSerif:GUILT}}"
label val mcat2 mcat2

histogram owninterest, by(mcat2, note("") col(2) graphregion(color(white)) ) gap(40) percent discrete xlabel(1(1)5) ylabel( , nogrid)  ///
xlabel(1 "very unlikely" 2 "quite unlikely" 3 "unsure" 4 "quite likely" 5 "very likely", noticks alternate labsize(3)) ///
ytitle("% of subjects") bcolor(navy) xtitle("") plotregion(fcolor(gray) intensity(15))

graph export "OA_Fig18b.pdf", replace 
graph export "OA_Fig18b.eps", replace


// OA-E.1 FIGURE 21 
gen interested = 0
replace interested = 1 if storyinterest>=3 | selectinterest>=3

gen story_thought=0
replace story_thought=1 if surprise >=3


collapse (mean) belieflearn learned story_thought interested if menuselection==3, by(owninterest)

replace belieflearn = round(belieflearn, 0.01)
replace learned = round(learned, 0.01)
replace interested = round(interested, 0.01)
replace story_thought = round(story_thought, 0.01)

twoway scatter belieflearn owninterest, mlabel(belieflearn) mlabposition(12) connect(ascending) ytitle("fraction of subjects") xtitle("belief about self") lpattern()  msymbol(circle) ylab(0(0.2)1, nogrid) graphregion(color(white)) || ///
scatter learned owninterest, mlabel(learned) mlabposition(6) connect(ascending) xtitle("belief about self") lpattern(dash) ylab(0(0.2)1, nogrid) graphregion(color(white)) || ///
scatter interested owninterest, mlabel(interested) mlabposition(6) connect(ascending) xtitle("belief about self") msymbol(circle_hollow) ylab(0(0.2)1, nogrid) graphregion(color(white)) || ///
scatter story_thought owninterest, mlabel(story_thought) mlabposition(12) connect(ascending) xtitle("belief about self") lpattern(solid) msymbol(i) ///
xlabel(1 "very unlikely" 2 "quite unlikely" 3 "unsure" 4 "quite likely" 5 "very likely", labsize(2.7)) ylab(0(0.2)1, nogrid) graphregion(color(white)) ///
legend(lab(1 "guessed other would read") lab(2 "chose to read") lab(3 "interested ex ante") lab(4 "distracted ex post")) saving(OA_Fig21, replace)

graph export "OA_Fig21.pdf", replace 
graph export "OA_Fig21.eps", replace


// Statistics reported on p.21-22 of main draft

ta learned if menuselection==3 & pref_0 ==1
ta learned if menuselection==3 & pref_1 ==1

gen strict_pref = 0 if pref_0==1
replace strict_pref = 1 if pref_1 ==1
ttest learned if menuselection==3, by(strict_pref)

ta learned if menuselection==3 & pref_0_alt ==1
ta learned if menuselection==3 & pref_1_alt ==1

gen strict_pref_alt = 0 if pref_0_alt==1
replace strict_pref_alt = 1 if pref_1_alt ==1
ttest learned if menuselection==3, by(strict_pref_alt)

gen sc = (menutype==2)
gen sc_alt = (alt_ranking2==2)

ttest learned if menuselection==3, by(sc)
ttest learned if menuselection==3, by(sc_alt)

******************************************
/// 4.2.2 Is there a cost of self-control?
******************************************

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

// t-test results reported on p.23 of the main text

gen menu_commit = 0
replace menu_commit = 1 if menuselection==1 
replace menu_commit = . if menuselection==2

ttest total_correct, by(menu_commit)
ttest all_correct, by(menu_commit)


// OA-C.3 FIGURE 8: Comparison of raw averages - full sample

gen perc_allcorrect = all_correct*100

graph bar (mean) perc_allcorrect,  over(menu_commit, relabel(1 "received {0,1}" 2 "received {0}")) /// 
ytitle("")  ///
asyvars bar(1, color(red*0.4) lcolor(red*0.9)) bar(2, color(navy)) ///
title("% with perfect score", size(4.8))  ylab(0(20)100, nogrid) graphregion(color(white)) blabel(bar, position(outside) format(%9.1f) size(3)) saving(g1, replace) nodraw

graph bar (mean) total_correct, over(menu_commit, relabel(1 "received {0,1}" 2 "received {0}")) /// 
ytitle("") ///
asyvars bar(1, color(red*0.4) lcolor(red*0.9)) bar(2, color(navy)) ///
title("mean number of correct answers", size(4.8)) ylab(0(1)5, nogrid) graphregion(color(white)) blabel(bar, position(outside) format(%9.1f) size(3)) saving(g2, replace) nodraw

grc1leg g1.gph g2.gph, graphregion(color(white)) saving(OA_Fig8, replace)

graph export "OA_Fig8.pdf", replace 
graph export "OA_Fig8.eps", replace


// Regression analysis for TABLE 5 of the main text

gen m3 = (menuselection==3)
replace m3 = . if menuselection==2

ta session, g(s_)

reg all_correct m3 s_*  // **
reg all_correct odds_0 odds_01 s_*  // *
reg all_correct m3 odds_0 odds_01 s_* // *

reg total_correct m3 s_* if menuselection!=2 // *
reg total_correct odds_0 odds_01 s_* if menuselection!=2 // *
reg total_correct m3 odds_0 odds_01 s_* if menuselection!=2 // *

// Probit models mentioned in the footnote of Table 5
probit all_correct m3 s_* if menuselection!=2 // **
margins, dydx(*) atmeans

probit all_correct odds_0 odds_01 s_* if menuselection!=2 // *
margins, dydx(*) atmeans

probit all_correct m3 odds_0 odds_01 s_* if menuselection!=2 // *
margins, dydx(*) atmeans


// OA-C.3 TABLE 9: Propensity score matching estimates - matching based on initial rank ordering
// Matching over subsample of subjects who have a match assigned a different menu

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear


gen no_match = 0
replace no_match =1 if menutype==9 | menutype==11 | menutype==13 | menutype==7

gen m3 = (menuselection==3)
replace m3 = . if menuselection==2

gen pos_wtp1 = 0
replace pos_wtp1 = 1 if total_wtp1 >0

gen pos_wtp2 = 0
replace pos_wtp2 = 1 if total_wtp2 >0

nnmatch all_correct m3 menutype if no_match==0, m(1) exact(menutype) bias(bias)
nnmatch all_correct m3 menutype pos_wtp1 pos_wtp2 if no_match==0, m(1) exact(menutype) bias(bias)
nnmatch all_correct m3 menutype pos_wtp1 pos_wtp2 if no_match==0, m(1) exact(menutype pos_wtp1 pos_wtp2) bias(bias)

nnmatch total_correct m3 menutype if no_match==0, m(1) exact(menutype) bias(bias)
nnmatch total_correct m3 menutype pos_wtp1 pos_wtp2 if no_match==0, m(1) exact(menutype) bias(bias)
nnmatch total_correct m3 menutype pos_wtp1 pos_wtp2 if no_match==0, m(1) exact(menutype pos_wtp1 pos_wtp2) bias(bias)


// HETEROGENEITY

// OA-C.3 FIGURE 9 

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

gen perc_allcorrect = all_correct*100

gen menureceived = "received {0,1}" if menuselection==3
replace menureceived = "received {0}" if menuselection==1

// Belief conflict measures
gen read1 = 0
replace read1 = 1 if owninterest !=1

gen read2 = 0
replace read2 = 1 if belieflearn==1

// Preference conflict measures
gen rank1 = 0
replace rank1 =1 if menuchoice1 >= menuchoice2

gen rank1_bis = 0
replace rank1_bis = 1 if alt_ranking2==3 | alt_ranking2==4 | alt_ranking2==6 | alt_ranking2==7 | alt_ranking2==9 | alt_ranking2==11 | alt_ranking2==12 | alt_ranking2==13


ttest all_correct if menuselection!=2 & rank1==0, by(menuselection) 
ttest all_correct if menuselection!=2 & read2==0, by(menuselection) 

graph bar (mean) perc_allcorrect, over(menureceived)  over(read2, relabel(1 "guessed 0" 2 "guessed 1")) ytitle("")  ///
asyvars bar(1, color(red*0.4) lcolor(red*0.9)) bar(2, color(navy)) ///
title("Incentivized belief")  ylab(0(20)100, nogrid) graphregion(color(white)) blabel(bar, position(outside) format(%9.1f)) saving(g1, replace) nodraw

graph bar (mean) perc_allcorrect, over(menureceived) over(read1, relabel(1 "1 not envisioned" 2 "1 possible")) ytitle("") ///
asyvars bar(1, color(red*0.4) lcolor(red*0.9)) bar(2, color(navy)) ///
title("Unincentivized belief") ylab(0(20)100, nogrid) graphregion(color(white)) blabel(bar, position(outside) format(%9.1f)) saving(g2, replace) nodraw

graph bar (mean) perc_allcorrect, over(menureceived)  over(rank1, relabel(1 "{0} >{sub:1} {1}" 2 "{1} {&ge}{sub:1} {0}"))  ytitle("")  ///
asyvars bar(1, color(red*0.4) lcolor(red*0.9)) bar(2, color(navy)) ///
title("Initial rank ordering")  ylab(0(20)100, nogrid) graphregion(color(white)) blabel(bar, position(outside) format(%9.1f)) saving(g3, replace) nodraw

graph bar (mean) perc_allcorrect, over(menureceived) over(rank1_bis, relabel(1 "{0} >{sub:1} {1}" 2 "{1} {&ge}{sub:1} {0}"))  /// 
ytitle("") ///
asyvars bar(1, color(red*0.4) lcolor(red*0.9)) bar(2, color(navy)) ///
title("Ranking based on WTP") ylab(0(20)100, nogrid) graphregion(color(white)) blabel(bar, position(outside) format(%9.1f)) saving(g4, replace) nodraw

grc1leg g1.gph g2.gph g3.gph g4.gph, title("% with perfect score") graphregion(color(white)) saving(OA_Fig9, replace)

graph export "OA_Fig9.pdf", replace 
graph export "OA_Fig9.eps", replace


// OA-C.3 TABLE 10 

gen m3 = (menuselection==3)
replace m3 = . if menuselection==2

gen m3_read1 = m3*read1
gen m3_read2 = m3*read2
gen m3_rank1 = m3*rank1
gen m3_rank1bis = m3*rank1_bis

reg all_correct rank1 m3 m3_rank1 rank1##c.odds_0 rank1##c.odds_1 rank1##i.session 
test m3 + m3_rank1 = 0

reg all_correct rank1_bis m3 m3_rank1bis rank1_bis##c.odds_0 rank1_bis##c.odds_1 rank1_bis##i.session 
test m3 + m3_rank1bis = 0

reg all_correct read1 m3 m3_read1 read1##c.odds_0 read1##c.odds_1 read1##i.session 
test m3 + m3_read1 = 0

reg all_correct read2 m3 m3_read2 read2##c.odds_0 read2##c.odds_1 read2##i.session 
test m3 + m3_read2 = 0

// Not reported - coeff on m3 not significant in 3 of the 4 regressions although the sign is indeed negative
reg total_correct rank1 m3 m3_rank1 rank1##c.odds_0 rank1##c.odds_1 rank1##i.session 
test m3 + m3_rank1 = 0

reg total_correct rank1_bis m3 m3_rank1bis rank1_bis##c.odds_0 rank1_bis##c.odds_1 rank1_bis##i.session
test m3 + m3_rank1bis = 0 

reg total_correct read1 m3 m3_read1 read1##c.odds_0 read1##c.odds_1 read1##i.session 
test m3 + m3_read1 = 0

reg total_correct read2 m3 m3_read2 read2##c.odds_0 read2##c.odds_1 read2##i.session 
test m3 + m3_read2 = 0


// OA-C.3.3 FIGURE 10

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

gen mcat1 = 1 if menutype==1
replace mcat1 = 2 if menutype==2
replace mcat1 = 3 if menutype==5
replace mcat1 = 4 if menutype==8
replace mcat1 = 5 if menutype==7 | menutype==12 | menutype==13
replace mcat1 = 6 if menutype==3 | menutype==4 | menutype==6 | menutype==9 | menutype==11

gen mcat2 = 1 if alt_ranking2==1
replace mcat2 = 2 if alt_ranking2==2
replace mcat2 = 3 if alt_ranking2==5
replace mcat2 = 4 if alt_ranking2==8
replace mcat2 = 5 if alt_ranking2==7 | alt_ranking2==12 | alt_ranking2==13 
replace mcat2 = 6 if alt_ranking2==3 | alt_ranking2==4 |  alt_ranking2==6 | alt_ranking2==9 | alt_ranking2==11

gen all_1 = all_correct if menuselection==1
gen all_3 = all_correct if menuselection==3


graph bar (mean) all_3 all_1, over(mcat1, relabel(1 "{it:{stSerif:GUILT}}" 2 "{it:{stSerif:SSB_{subscript:0}}}" 3 "{it:{stSerif:FLEX_{subscript:0}}}" 4 "{it:{stSerif:STD_{subscript:0}}}" 5 "{1} ={sub:1} {0}" 6 "{1} >{sub:1} {0}")) ///
ytitle("fraction of subjects") yvaroptions(relabel(1 "received {0,1}" 2 "received {0}")) title("classification based on rank ordering") ylab(0(0.2)1, nogrid)  blabel(bar, position(outside) format(%9.2f)) graphregion(color(white))  bar(1, color(red*0.4) lcolor(red*0.9)) bar(2, color(navy)) saving(f1, replace) nodraw
graph bar (mean) all_3 all_1, over(mcat2, relabel(1 "{it:{stSerif:GUILT}}" 2 "{it:{stSerif:SSB_{subscript:0}}}" 3 "{it:{stSerif:FLEX_{subscript:0}}}" 4 "{it:{stSerif:STD_{subscript:0}}}" 5 "{1} ={sub:1} {0}" 6 "{1} >{sub:1} {0}")) title("classification based on {it:{stSerif:WTP}}") ///
ytitle("fraction of subjects") ylab(0(0.2)1, nogrid) graphregion(color(white)) blabel(bar, position(outside) format(%9.2f))  bar(1, color(red*0.4) lcolor(red*0.9)) bar(2, color(navy)) saving(f2, replace) nodraw
grc1leg f1.gph f2.gph, col(1) graphregion(color(white)) saving(OA_Fig10, replace)

graph export "OA_Fig10.pdf", replace 
graph export "OA_Fig10.eps", replace

// OA-C.3.4 FIGURE 11 

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

gen perc_allcorrect = all_correct*100

gen menureceived = "received {0,1}" if menuselection==3
replace menureceived = "received {0}" if menuselection==1

gen WTP = "WTP{sub:{0}} = 0" if total_wtp1 ==0
replace WTP = "WTP{sub:{0}} > 0" if total_wtp1 >0

gen story_thought = 0
replace story_thought = 1 if surprise >=3

replace story_thought = 100*story_thought

graph bar (mean) story_thought if menutype==2,  over(WTP) over(menureceived)  ytitle("")  ///
asyvars bar(1, color(navy)) bar(2, color(red*0.4) lcolor(red*0.9)) ///
title("% who thought about the story")  ylab(0(20)100, nogrid) graphregion(color(white)) blabel(bar, position(outside) format(%9.1f)) saving(g1, replace) nodraw


graph bar (mean) perc_allcorrect if menutype==2,  over(WTP) over(menureceived) ytitle("")  ///
asyvars bar(1, color(navy)) bar(2, color(red*0.4) lcolor(red*0.9))  ///
title("% with perfect score")  ylab(0(20)100, nogrid) graphregion(color(white)) blabel(bar, position(outside) format(%9.1f)) saving(g2, replace) nodraw

grc1leg g1.gph g2.gph, graphregion(color(white)) saving(OA_Fig11, replace)

graph export "OA_Fig11.pdf", replace 
graph export "OA_Fig11.eps", replace


// OA-C.3.4 FIGURE 12

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

gen menureceived = "received {0,1}" if menuselection==3
replace menureceived = "received {0}" if menuselection==1

gen read1 = 0
replace read1 = 1 if owninterest !=1

gen read2 = 0
replace read2 = 1 if belieflearn==1

gen rank1 = 0
replace rank1 =1 if menuchoice1 >= menuchoice2

gen rank1_bis = 0
replace rank1_bis = 1 if alt_ranking2==3 | alt_ranking2==4 | alt_ranking2==6 | alt_ranking2==7 | alt_ranking2==9 | alt_ranking2==11 | alt_ranking2==12 | alt_ranking2==13

gen story_thought = 0
replace story_thought = 1 if surprise >=3

replace story_thought = 100*story_thought


graph bar (mean) story_thought, over(menureceived)  over(read2, relabel(1 "guessed 0" 2 "guessed 1")) ytitle("")  ///
asyvars bar(1, color(red*0.4) lcolor(red*0.9)) bar(2, color(navy)) ///
title("Incentivized belief")  ylab(0(20)100, nogrid) graphregion(color(white)) blabel(bar, position(outside) format(%9.1f)) saving(g1, replace) nodraw

graph bar (mean) story_thought, over(menureceived) over(read1, relabel(1 "1 not envisioned" 2 "1 possible")) ytitle("") ///
asyvars bar(1, color(red*0.4) lcolor(red*0.9)) bar(2, color(navy)) ///
title("Unincentivized belief") ylab(0(20)100, nogrid) graphregion(color(white)) blabel(bar, position(outside) format(%9.1f)) saving(g2, replace) nodraw

graph bar (mean) story_thought, over(menureceived)  over(rank1, relabel(1 "{0} >{sub:1} {1}" 2 "{1} {&ge}{sub:1} {0}"))  ytitle("")  ///
asyvars bar(1, color(red*0.4) lcolor(red*0.9)) bar(2, color(navy)) ///
title("Initial rank ordering")  ylab(0(20)100, nogrid) graphregion(color(white)) blabel(bar, position(outside) format(%9.1f)) saving(g3, replace) nodraw

graph bar (mean) story_thought, over(menureceived) over(rank1_bis, relabel(1 "{0} >{sub:1} {1}" 2 "{1} {&ge}{sub:1} {0}"))  /// 
ytitle("") ///
asyvars bar(1, color(red*0.4) lcolor(red*0.9)) bar(2, color(navy)) ///
title("Ranking based on WTP") ylab(0(20)100, nogrid) graphregion(color(white)) blabel(bar, position(outside) format(%9.1f)) saving(g4, replace) nodraw


grc1leg g1.gph g2.gph g3.gph g4.gph, title("% who paid attention to the story", size(4.5)) graphregion(color(white)) saving(OA_Fig12, replace)


graph export "OA_Fig12.pdf", replace 
graph export "OA_Fig12.eps", replace


**************************************************************
// 4.3.2 Can temptation uncertainty explain commitment demand?
**************************************************************

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

// FIGURE 4 Appendix main text

histogram owninterest if menutype==2, gap(40) percent discrete xlabel(1(1)6) ylabel( , nogrid)  ///
xlabel(1 "very unlikely" 2 "quite unlikely" 3 "unsure" 4 "quite likely" 5 "very likely" 6 " ", alternate labsize(3) noticks)  ///
ytitle("% of subjects") bcolor(navy) xtitle("") graphregion(color(white)) saving(main_Fig4, replace)

graph export "main_Fig4.pdf", replace 
graph export "main_Fig4.eps", replace

gen may_read = 0
replace may_read = 1 if owninterest >1

gen interested = 0
replace interested = 1 if storyinterest >=3 | selectinterest >=3 

ta may_read interested if menutype==2, row col exact

gen interest_level = (storyinterest + selectinterest)/2
spearman interest_level owninterest if menutype==2
ci2 interest_level owninterest if menutype==2, corr spearman // rho = 0.497 on 43 observations (95% CI: 0.231 to 0.694) 
bootstrap corr = r(rho), reps(2000): spearman interest_level owninterest if menutype==2 

ksmirnov interest_level if menutype==2, by(may_read)

// FIGURE 5 Appendix main text

histogram total_wtp1 if menutype==2 & may_read==0, bcolor(navy) percent gap(40) discrete xlabel(0(1)8) xtitle("{it:{stSerif:WTP}} frequency in the MPL")  ytitle("% of subjects") ylabel(0(10)50, nogrid) title("Expects not to read") graphregion(color(white))  saving(h1, replace)  nodraw
histogram total_wtp1 if menutype==2 & may_read==1, bcolor(navy) percent gap(40) discrete xlabel(0(1)8) xtitle("{it:{stSerif:WTP}} frequency in the MPL")  ytitle("% of subjects") ylabel(0(10)50, nogrid) title("May read") graphregion(color(white))  saving(h2, replace) nodraw
graph combine h1.gph h2.gph, title("Panel A: {it:{stSerif:WTP}} and beliefs")  graphregion(color(white)) saving(h5, replace)

histogram total_wtp1 if menutype==2 & interested==0, bcolor(navy) percent gap(40) discrete xlabel(0(1)8) xtitle("{it:{stSerif:WTP}} frequency in the MPL") ytitle("% of subjects") ylabel(0(10)50, nogrid) title("Indifferent")  graphregion(color(white))  saving(h3, replace) nodraw
histogram total_wtp1 if menutype==2 & interested==1, bcolor(navy) percent gap(40) discrete xlabel(0(1)8) xtitle("{it:{stSerif:WTP}} frequency in the MPL") ytitle("% of subjects") ylabel(0(10)50, nogrid) title("Interested")  graphregion(color(white))  saving(h4, replace) nodraw
graph combine h3.gph h4.gph, title("Panel B: {it:{stSerif:WTP}} and interest for the story")  graphregion(color(white))  saving(h6, replace)

graph combine h5.gph h6.gph, col(1)  graphregion(color(white)) saving(main_Fig5, replace)

graph export "main_Fig5.pdf", replace 
graph export "main_Fig5.eps", replace

// Reported statistics p.28

ksmirnov total_wtp1 if menutype==2, by(may_read)

gen max_WTP = 0
replace max_WTP = 1 if total_wtp1==8

ttest max_WTP if menutype==2, by(interested)

replace ptime1 = ptime1/60
replace ptime2 = ptime2/60

gen norm_time1 = 0 if ptime1 !=.
replace norm_time1 = 0.01 if ptime1 == 1
replace norm_time1 = 0.5 if ptime1 == 10
replace norm_time1 = 0.01 +  0.5*(ptime1-1)/(10-1) if ptime1 !=0 & ptime1 !=10 & ptime1 !=.

gen norm_time2 = 0 if ptime2 !=.
replace norm_time2 = 0.01 if ptime2 == 1
replace norm_time2 = 0.5 if ptime2 == 10
replace norm_time2 = 0.01 +  0.5*(ptime2-1)/(10-1) if ptime2 !=0 & ptime2 !=10 & ptime2 !=.

rename strict_12 strict1
rename strict_23 strict2

rename wtp1_total wtp_total1
rename wtp2_total wtp_total2
rename tc1_total tc_total1
rename tc2_total tc_total2

reshape long money norm_time wtp_total tc_total indiff strict, i(id) j(comparison_rank)

gen wtp_replace = money 
replace wtp_replace = norm_time if money ==.

ttest wtp_replace if menutype==2 & comparison_rank==1, by(may_read) // $0.15 vs $0.13, p = 0.732
ttest wtp_replace if menutype==2 & comparison_rank==1, by(interested) // $0.20 vs $0.07, p = 0.028 

spearman wtp_replace owninterest if menutype==2 & comparison_rank==1 // rho = -0.077, p = 0.622
ci2 wtp_replace owninterest if menutype==2 & comparison_rank==1, corr spearman // 95% CI: -0.369 to 0.228
bootstrap corr = r(rho), reps(2000) seed(1986): spearman wtp_replace owninterest if menutype==2 & comparison_rank==1 // 95% CI: -0.389 to 0.234
estat bootstrap, all

// TABLE 7 main text - N.b: owninterest is the variable called "Chances of reading"

ta session, gen(s_)

gen time_wtp = 0
replace time_wtp = 1 if tc1_choice1 !=.

keep if menutype==2 & comparison_rank==1

tobit wtp_replace interested time_wtp s_*, ll(0) ul(0.5)
tobit wtp_replace interest_level time_wtp s_*, ll(0) ul(0.5)

tobit wtp_replace may_read time_wtp s_*, ll(0) ul(0.5)
tobit wtp_replace owninterest time_wtp s_*, ll(0) ul(0.5)

tobit wtp_replace interested owninterest time_wtp s_*, ll(0) ul(0.5)
tobit wtp_replace interest_level owninterest time_wtp s_*, ll(0) ul(0.5)

tobit wtp_replace interested may_read time_wtp s_*,  ll(0) ul(0.5)
tobit wtp_replace interest_level may_read time_wtp s_*, ll(0) ul(0.5)


// OA-D.1 TABLE 11  - N.b: owninterest is the variable called "Chances of reading"

// Regressions without session FE


tobit wtp_replace interested time_wtp, ll(0) ul(0.5) // **
tobit wtp_replace interest_level time_wtp, ll(0) ul(0.5) // *

tobit wtp_replace may_read time_wtp, ll(0) ul(0.5)
tobit wtp_replace owninterest time_wtp, ll(0) ul(0.5)

tobit wtp_replace interested owninterest time_wtp, ll(0) ul(0.5) // **
tobit wtp_replace interest_level owninterest time_wtp, ll(0) ul(0.5) // **

tobit wtp_replace interested may_read time_wtp,  ll(0) ul(0.5) // **
tobit wtp_replace interest_level may_read time_wtp, ll(0) ul(0.5) // **


// Bootstrap estimations - no session FE

bootstrap, reps(2000) seed(1986) bca: tobit wtp_replace interested time_wtp if menutype==2 & comparison_rank==1,  ll(0) ul(0.5) // *
estat bootstrap, all

bootstrap, reps(2000) seed(1986) bca: tobit wtp_replace interest_level time_wtp if menutype==2 & comparison_rank==1,  ll(0) ul(0.5) // *
estat bootstrap, all

bootstrap, reps(2000) seed(1986) bca: tobit wtp_replace may_read time_wtp if menutype==2 & comparison_rank==1,  ll(0) ul(0.5)
estat bootstrap, all

bootstrap, reps(2000) seed(1986) bca: tobit wtp_replace owninterest time_wtp if menutype==2 & comparison_rank==1,  ll(0) ul(0.5)
estat bootstrap, all

bootstrap, reps(2000) seed(1986) bca: tobit wtp_replace interested owninterest time_wtp if menutype==2 & comparison_rank==1,  ll(0) ul(0.5) // **
estat bootstrap, all

bootstrap, reps(2000) seed(1986) bca: tobit wtp_replace interest_level owninterest time_wtp if menutype==2 & comparison_rank==1,  ll(0) ul(0.5) // **
estat bootstrap, all 

bootstrap, reps(2000) seed(1986) bca: tobit wtp_replace interested may_read time_wtp if menutype==2 & comparison_rank==1,  ll(0) ul(0.5) // **
estat bootstrap, all

bootstrap, reps(2000) seed(1986) bca: tobit wtp_replace interest_level may_read time_wtp if menutype==2 & comparison_rank==1,  ll(0) ul(0.5) // *
estat bootstrap, all


// OA-D.1 TABLE 12  - N.b: owninterest is the variable called "Chances of reading"

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

ta session, gen(s_)

gen time_wtp = 0
replace time_wtp = 1 if tc1_choice1 !=.

gen may_read = 0
replace may_read = 1 if owninterest >1

gen interested = 0
replace interested = 1 if storyinterest >=3 | selectinterest >=3 

// OA-D.1 FIGURE 14 

ta may_read interested if menutype==2, row col exact

gen interest_level = (storyinterest + selectinterest)/2

twoway kdensity interest_level if may_read ==0 & menutype==2, legend(label(1 "Expects not to read")) lpattern(solid) lwidth(0.5) graphregion(color(white)) ylabel( , nogrid) || /// 
kdensity interest_level if may_read ==1 & menutype==2, legend(label(2 "May read")) lpattern(dash) xtitle("Interest level") lwidth(0.5) ///
ytitle("kernel density") saving(OA_Fig14, replace) 
graph export "OA_Fig14.pdf", replace 
graph export "OA_Fig14.eps", replace

ksmirnov interest_level if menutype==2, by(may_read) // p = 0.013

// OA-D.1 TABLE 12  - N.b: owninterest is the variable called "Chances of reading"

reg total_wtp1 interested time_wtp s_* if menutype==2
reg total_wtp1 interest_level time_wtp s_* if menutype==2

reg total_wtp1 may_read time_wtp s_* if menutype==2
reg total_wtp1 owninterest time_wtp s_* if menutype==2

reg total_wtp1 interested owninterest time_wtp s_* if menutype==2 & owninterest
reg total_wtp1 interest_level owninterest time_wtp s_* if menutype==2 & owninterest 

reg total_wtp1 interested may_read time_wtp s_* if menutype==2 & owninterest
reg total_wtp1 interest_level may_read time_wtp s_* if menutype==2 & owninterest 


//  OA-D.1 TABLE 13  - N.b: owninterest is the variable called "Chances of reading"

// First 4 columns
reg total_wtp2 owninterest s_* if menutype==2
reg total_wtp2 owninterest total_wtp1 time_wtp s_* if menutype==2
reg total_wtp2 may_read s_* if menutype==2
reg total_wtp2 may_read total_wtp1 time_wtp s_* if menutype==2

// Last 4 columns
replace ptime1 = ptime1/60
replace ptime2 = ptime2/60

gen norm_time1 = 0 if ptime1 !=.
replace norm_time1 = 0.01 if ptime1 == 1
replace norm_time1 = 0.5 if ptime1 == 10
replace norm_time1 = 0.01 +  0.5*(ptime1-1)/(10-1) if ptime1 !=0 & ptime1 !=10 & ptime1 !=.

gen norm_time2 = 0 if ptime2 !=.
replace norm_time2 = 0.01 if ptime2 == 1
replace norm_time2 = 0.5 if ptime2 == 10
replace norm_time2 = 0.01 +  0.5*(ptime2-1)/(10-1) if ptime2 !=0 & ptime2 !=10 & ptime2 !=.

rename strict_12 strict1
rename strict_23 strict2

rename wtp1_total wtp_total1
rename wtp2_total wtp_total2
rename tc1_total tc_total1
rename tc2_total tc_total2

reshape long money norm_time wtp_total tc_total indiff strict, i(id) j(comparison_rank)

gen wtp_replace = money 
replace wtp_replace = norm_time if money ==.

reshape wide wtp_replace money norm_time wtp_total tc_total indiff strict, i(id) j(comparison_rank) 

tobit wtp_replace2 owninterest s_* if menutype==2, ll(0) ul(0.5)
tobit wtp_replace2 owninterest wtp_replace1 time_wtp s_* if menutype==2, ll(0) ul(0.5)

tobit wtp_replace2 may_read s_* if menutype==2,  ll(0) ul(0.5)
tobit wtp_replace2 may_read wtp_replace1 time_wtp s_* if menutype==2, ll(0) ul(0.5)


// OA-D.1 FIGURE 13  

gen wtp_gr1 = 1 if wtp_replace1 ==0
replace wtp_gr1 = 2 if wtp_replace1 < 0.2 & wtp_replace1 > 0 
replace wtp_gr1 = 3 if wtp_replace1 >= 0.1 & wtp_replace1 < 0.2
replace wtp_gr1 = 4 if wtp_replace1 >= 0.2 & wtp_replace1 < 0.5
replace wtp_gr1 = 5 if wtp_replace1 >=0.5

histogram wtp_gr1 if menutype==2, percent discrete gap(40) xtitle("dollar amount") bcolor(navy) ///
ylab(0(10)50, nogrid) ytitle("% of subjects") graphregion(color(white)) ///
xlabel(1 "0" 2 "(0, 0.10)" 3 "[0.10, 0.20)" 4 "[0.20, 0.50)" 5 "0.50" 6 " ") saving(OA_Fig13, replace) 

graph export "OA_Fig13.pdf", replace 
graph export "OA_Fig13.eps", replace

// OA-D.1 FIGURE 15  

gen wtp_gr2 = 1 if wtp_replace2 ==0
replace wtp_gr2 = 2 if wtp_replace2 < 0.2 & wtp_replace2 > 0 
replace wtp_gr2 = 3 if wtp_replace2 >= 0.1 & wtp_replace2 < 0.2
replace wtp_gr2 = 4 if wtp_replace2 >= 0.2 & wtp_replace2 < 0.5
replace wtp_gr2 = 5 if wtp_replace2 >=0.5

histogram wtp_gr2 if menutype==2, percent discrete gap(40) xtitle("dollar amount") bcolor(navy) ///
ylab(0(10)50, nogrid) ytitle("% of subjects") graphregion(color(white)) ///
xlabel(1 "0" 2 "(0, 0.10)" 3 "[0.10, 0.20)" 4 "[0.20, 0.50)" 5 "0.50" 6 " ") saving(OA_Fig15, replace) 

graph export "OA_Fig15.pdf", replace 
graph export "OA_Fig15.eps", replace


**************************
// OA-D.2: WTP CALIBRATION
**************************

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

gen likelihood_right = total_correct/5 // denoted \hat{\pi_i} in OA-D.2


// OA-D.2 FIGURE 17(a) 

histogram likelihood_right if menutype==2, discrete percent discrete gap(40) xtitle(" ") ytitle("% of subjects") graphregion(color(white)) ///
bcolor(navy) xlabel(0(0.2)1) saving(OA_Fig17a, replace)
graph export "OA_Fig17a.pdf", replace 
graph export "OA_Fig17a.eps", replace


// Computation of E(L) as described p.32-33 of OA-D.2

replace ptime1 = ptime1/60
replace ptime2 = ptime2/60

gen norm_time1 = 0 if ptime1 !=.
replace norm_time1 = 0.01 if ptime1 == 1
replace norm_time1 = 0.5 if ptime1 == 10
replace norm_time1 = 0.01 +  0.5*(ptime1-1)/(10-1) if ptime1 !=0 & ptime1 !=10 & ptime1 !=.

gen norm_time2 = 0 if ptime2 !=.
replace norm_time2 = 0.01 if ptime2 == 1
replace norm_time2 = 0.5 if ptime2 == 10
replace norm_time2 = 0.01 +  0.5*(ptime2-1)/(10-1) if ptime2 !=0 & ptime2 !=10 & ptime2 !=.

rename strict_12 strict1
rename strict_23 strict2

rename wtp1_total wtp_total1
rename wtp2_total wtp_total2
rename tc1_total tc_total1
rename tc2_total tc_total2

reshape long money norm_time wtp_total tc_total indiff strict, i(id) j(comparison_rank)

gen wtp_replace = money 
replace wtp_replace = norm_time if money ==.

drop if comparison_rank ==2

egen cts_belief = mean(belieflearn), by(owninterest) // denoted \hat{\lambda_i}

gen exp_L = likelihood_right*cts_belief*2

gen censored_exp_L = exp_L
replace censored_exp_L = 0.5 if exp_L >0.5

ttest exp_L = wtp_replace if menutype==2 // 0.14 in both, p = 0.959
ttest exp_L = wtp_replace if exp_L <= 0.5 & menutype==2 // 0.11 vs 0.14, p = 0.220


// Reported correlation coefficients with confidence intervals based on Fisher's transformation
// Using beliefs about similar other to calibrate subjective beliefs


pwcorr wtp_replace exp_L if menutype==2, sig // rho = -0.05, p=0.743
ci2 wtp_replace exp_L if menutype==2, corr // 95% CI: -0.346 to 0.253

pwcorr wtp_replace exp_L if menutype==2 & exp_L <= 0.5, sig // rho = 0.21, p=0.18
ci2 wtp_replace exp_L if menutype==2 & exp_L <= 0.5, corr // 95% CI: -0.100 to 0.483

spearman wtp_replace exp_L if menutype==2 // rho = 0.05, p = 0.743
ci2 wtp_replace exp_L if menutype==2, corr spearman // 95% CI: -0.253 to 0.347

spearman wtp_replace exp_L if menutype==2 & exp_L <= 0.5 // rho = 0.10, p = 0.533
ci2 wtp_replace exp_L if menutype==2 & exp_L <= 0.5, corr spearman // 95% CI: -0.211 to 0.391


// Reported correlation coefficients with confidence intervals based on Fisher's transformation
// Using survey responses from a convenience sample (N=15 students) to calibrate subjective beliefs - see footnote 15 OA-D.2

gen cts_belief2 = 0.10 if owninterest==1
replace cts_belief2 = 0.20 if owninterest==2
replace cts_belief2 = 0.50 if owninterest==3
replace cts_belief2 = 0.70 if owninterest==4
replace cts_belief2 = 0.90 if owninterest==5

gen exp_L2 = likelihood_right*cts_belief2*2

pwcorr wtp_replace exp_L2 if menutype==2, sig // rho = 0.063, p=0.686
ci2 wtp_replace exp_L2 if menutype==2, corr // 95% CI: -0.241 to 0.357

pwcorr wtp_replace exp_L2 if menutype==2 & exp_L2 <= 0.5, sig // rho = 0.113, p=0.487
ci2 wtp_replace exp_L2 if menutype==2 & exp_L2 <= 0.5, corr // 95% CI: -0.206 to 0.410

spearman wtp_replace exp_L2 if menutype==2 // rho = 0.048, p = 0.759
ci2 wtp_replace exp_L2 if menutype==2, corr spearman // 95% CI: -0.256 to 0.344

spearman wtp_replace exp_L2 if menutype==2 & exp_L2 <= 0.5 // rho = 0.084, p = 0.608
ci2 wtp_replace exp_L2 if menutype==2 & exp_L2 <= 0.5, corr spearman // 95% CI: -0.234 to 0.385


// OA-D.2 FIGURE 17(b) 

drop if menutype!=2
gen graph_id = _n
twoway scatter wtp_replace graph_id, msymbol(triangle) || scatter censored_exp_L graph_id, msymbol(circle_hollow) graphregion(color(white)) ///
legend(label(1 "WTP"))  legend(label(2 "Estimated E(L)")) xtitle("subject id") saving(OA_Fig17b, replace)
graph export "OA_Fig17b.pdf", replace 
graph export "OA_Fig17b.eps", replace

// OA-D.2 FIGURE 17(c) 

contract censored_exp_L wtp_replace 
scatter wtp_replace censored_exp_L [w=_freq], msymbol(circle_hollow) graphregion(color(white)) ///
xtitle("estimated {it:{stSerif:E(L)}} in $") ytitle("{it:{stSerif:WTP}} for {stSerif:{0}} in $") saving(OA_Fig17c, replace)
graph export "OA_Fig17c.pdf", replace 
graph export "OA_Fig17c.eps", replace



// Computation of confidence intervals allowing for measurement error - see footnote 15 OA-D.2

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

gen likelihood_right = total_correct/5 

replace ptime1 = ptime1/60
replace ptime2 = ptime2/60

gen norm_time1 = 0 if ptime1 !=.
replace norm_time1 = 0.01 if ptime1 == 1
replace norm_time1 = 0.5 if ptime1 == 10
replace norm_time1 = 0.01 +  0.5*(ptime1-1)/(10-1) if ptime1 !=0 & ptime1 !=10 & ptime1 !=.

gen norm_time2 = 0 if ptime2 !=.
replace norm_time2 = 0.01 if ptime2 == 1
replace norm_time2 = 0.5 if ptime2 == 10
replace norm_time2 = 0.01 +  0.5*(ptime2-1)/(10-1) if ptime2 !=0 & ptime2 !=10 & ptime2 !=.

rename strict_12 strict1
rename strict_23 strict2

rename wtp1_total wtp_total1
rename wtp2_total wtp_total2
rename tc1_total tc_total1
rename tc2_total tc_total2

reshape long money norm_time wtp_total tc_total indiff strict, i(id) j(comparison_rank)

gen wtp_replace = money 
replace wtp_replace = norm_time if money ==.

gen sc_type = (menutype==2)

drop if comparison_rank ==2

ta owninterest, g(o_)
gen nsamp = cond(sc_type, 43, 77) 

regress belieflearn o_*, nocons
predict b_hat2
gen e_pi2 = likelihood_right*b_hat2*2 
corr wtp_replace e_pi2 if menutype==2 & e_pi2 <=0.5
mat rho1 =r(rho)
mat l rho1

capture program drop bootex
program define bootex, eclass
preserve 
	bsample nsamp, strata(sc_type) 
	reg belieflearn o_*, nocons
	predict belief_hat
	gen exp_prod_loss = likelihood_right*belief_hat*2 
	corr wtp_replace exp_prod_loss if menutype==2 & exp_prod_loss <=0.5
	matrix rho2 = e(rho)
	ereturn scalar rho2 = e(rho)
	restore 
end


simulate rho2 = r(rho), reps(2000) seed(1986): bootex
bstat, stat(rho1)  n(42)
estat bootstrap, all

// CI for Pearson's correlation (all):  [-0.2285845, 0.455837]
// CI for Pearson's rho (N=42): [-0.155224, 0.5909583]

// CI for Spearman (all):  [-0.279595, 0.3969283]
// CI for Spearman (N=42): [-0.2523051, 0.4475699]


********************************
// OA-B: CURIOSITY FOR THE STORY
********************************

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

// OA-B.1 FIGURE 3(a)

gen interest_level = (storyinterest + selectinterest)/2

histogram interest_level, discrete percent discrete gap(40) xtitle(" ") ytitle("% of subjects") graphregion(color(white)) ///
bcolor(navy) xlabel(1(0.5)5) xtitle("Interest level") saving(OA_Fig3a, replace)

graph export "OA_Fig3a.pdf", replace 
graph export "OA_Fig3a.eps", replace

// OA-B.1 FIGURE 3(b)

gen min_interest = 0
replace min_interest = 5 if storyinterest>=5 | selectinterest>=5
replace min_interest = 4 if (storyinterest>=4 | selectinterest>=4) & min_interest !=5
replace min_interest = 3 if (storyinterest>=3 | selectinterest>=3) & min_interest < 4
replace min_interest = 2 if (storyinterest>=2 | selectinterest>=2) & min_interest < 3
replace min_interest = 1 if storyinterest==1 & selectinterest==1

histogram min_interest, discrete percent discrete gap(40) xtitle(" ") ytitle("% of subjects") graphregion(color(white)) bcolor(navy) ///
xlabel(1 `" "completely" "indifferent" "'  2 `" "somewhat" "indifferent" "' 3 `" "somewhat" "interested" "' 4 `" "very" "interested" "' 5 `" "dying" "to learn" "' 6 " ") ///
saving(OA_Fig3b, replace)

graph export "OA_Fig3b.pdf", replace 
graph export "OA_Fig3b.eps", replace

ci2 storyinterest selectinterest, corr spearman

gen no_interest_select = 1 - (selectinterest >=3)
gen no_interest_story = 1 - (storyinterest >=3)

ta no_interest_story no_interest_select, row col chi2 // OA-B1 TABLE 4 

// OA-B.2 FIGURE 4(a) 

gen story_thought = (surprise>=3)
tab surprise, g(s_)
reshape long s_, i(id) j(resp_nbr)
gen s_commit = s_ if menuselection==1
gen s_flex = s_ if menuselection==3

graph bar s_, blabel(bar, position(outside) format(%9.2f) color(black))  legend( label(1 "received {0}") label(2 "received {0,1}") ) ///
over(resp_nbr, relabel(1 `" "no attention to story" "did not care" "' 2 `" "no attention to story" "too absorbed by task" "' 3 `" "thought about it after" "getting bored" "' ///
4 `" "kept wondering" "but stayed focused" "'  5   `" "kept wondering" "and could not focus" "') label(labsize(2.6) alternate)) ///
ylab(0(0.1)0.4, nogrid) graphregion(color(white)) ytitle("fraction of subjects") saving(OA_Fig4a, replace)

graph export "OA_Fig4a.pdf", replace 
graph export "OA_Fig4a.eps", replace


//  OA-B.2 FIGURE 4(b)

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

gen story_thought = (surprise>=3)

gen min_interest = 0
replace min_interest = 5 if storyinterest>=5 | selectinterest>=5
replace min_interest = 4 if (storyinterest>=4 | selectinterest>=4) & min_interest !=5
replace min_interest = 3 if (storyinterest>=3 | selectinterest>=3) & min_interest < 4
replace min_interest = 2 if (storyinterest>=2 | selectinterest>=2) & min_interest < 3
replace min_interest = 1 if storyinterest==1 & selectinterest==1

graph bar (mean) story_thought, over(min_interest, relabel(1 "completely indifferent" 2 "somewhat indifferent" 3 "somewhat interested" ///
4 "very interested" 5 "dying to learn") label(labsize(3.1) alternate)) /// 
blabel(bar, position(outside) format(%9.2f) color(black))  ytitle("fraction distracted by story") ///
ylab(0(0.2)0.8, nogrid) graphregion(color(white)) ytitle("fraction of subjects") saving(OA_Fig4b, replace) 

graph export "OA_Fig4b.pdf", replace 
graph export "OA_Fig4b.eps", replace

gen interest_level = (storyinterest + selectinterest)/2

ci2 interest_level surprise, corr spearman


// OA-B.2 TABLE 5 

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

gen no_interest_before = (storyinterest<=2 & selectinterest <=2)
gen no_interest_during = (surprise <3)
 
ta no_interest_before no_interest_during if menuselection==3, row col chi2 


// OA-B.3 TABLE 6 

gen female = (sex ==2)
gen econ = (major==4)
gen story_thought = (surprise>=3)

su female econ
su gpa if gpa >=0

gen EC = (ec1 + ec2 + ec3 + ec4 + ec5 + ec6 + ec7 + ec8 + ec9 + ec10)/10
gen CFD = (cd1 + cd2 + cd3 + cd4 + cd5 + cd6 + cd7 + icd8 + cd9 + cd10)/10
gen B5 = (bf1 + ibf2 + ibf3 + bf4 + ibf5 + bf6 + ibf7 + ibf8 + bf9 + ibf10)/10

su EC CFD B5
pwcorr EC CFD B5, sig 

su wtp_exit story_thought


// OA-B.3 FIGURE 5 

gen pos_wtp = (wtp_exit >0)

gen ranking1 = 1 if menuchoice2==1
replace ranking1 = 2 if menuchoice2==2
replace ranking1 = 3 if menuchoice2==3

graph bar (mean) pos_wtp wtp_exit, over(ranking1, relabel(1 "{1}  ranked first" 2 "{1}  ranked second" 3 "{1}  ranked last")) ///
bar(1, bcolor(navy)) bar(2, bcolor(red*0.4) lcolor(red*0.9)) legend(label(1 "fraction with WTP > 0") label(2 "average WTP in $")) ///
ylab(0(0.2)1, nogrid) blabel(bar, position(outside) format(%9.2f)) graphregion(color(white)) saving(OA_Fig5, replace) 
graph export "OA_Fig5.pdf", replace 
graph export "OA_Fig5.eps", replace

// OA-B.3 TABLE 7 

drop if menuselection!=3
reg learned story_thought 
reg learned story_thought pos_wtp
reg learned story_thought pos_wtp B5 EC
reg learned story_thought pos_wtp B5 CFD
reg learned story_thought pos_wtp B5 EC CFD


***********************************************
// OA-C: PRODUCTIVITY DURING THE ATTENTION TASK
***********************************************

// OA-C.1 TABLE 8 - last column 

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

drop if menuselection!=3

gen itime1 = 2127 // beginning of the counter for prompt 1
gen itime2 = 5069
gen itime3 = 1299
gen itime4 = 9546
gen itime5 = 4231

gen timelearned1 = endtime1 - remainingtime1
gen timelearned2 = endtime2 - remainingtime2
gen timelearned3 = endtime3 - remainingtime3
gen timelearned4 = endtime4 - remainingtime4
gen timelearned5 = endtime5 - remainingtime5

gen time2learn1 = timelearned1 - itime1
gen time2learn2 = timelearned2 - itime2
gen time2learn3 = timelearned3 - itime3
gen time2learn4 = timelearned4 - itime4
gen time2learn5 = timelearned5 - itime5


// 3rd column
su learned1 learned2 learned3 learned4 learned5

// Last column
su time2learn1 if menuselection==3 & learned1==1 
su time2learn2 if menuselection==3 & learned2==1
su time2learn3 if menuselection==3 & learned3==1
su time2learn5 if menuselection==3 & learned5==1


// OA-C.2 FIGURE 6(a) 

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

gen correct1  = correctanswer1 if learned1 !=1
gen correct2  = correctanswer2 if learned2 !=1
gen correct3  = correctanswer3 if learned3 !=1
gen correct4  = correctanswer4 if learned4 !=1
gen correct5  = correctanswer5 if learned5 !=1

reshape long correct, i(id) j(prompt_number)

replace correct = correct*100 

graph bar (mean) correct, over(prompt_number) blabel(bar, position(outside) format(%8.1f) color(black)) ///
ylabel( , nogrid) graphregion(color(white)) ytitle(" ") saving(OA_Fig6a, replace)

graph export "OA_Fig6a.pdf", replace 
graph export "OA_Fig6a.eps", replace


// OA-C.2 FIGURE 6(b)

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data/ /*current directory*/
insheet using "data_reshaped.csv", clear

histogram total_correct, percent discrete gap(40) addlabels addlabopts(yvarformat(%9.1f)) xtitle("number of correct answers") ///
ytitle("% of subjects") xlabel(0(1)5)  ylab(0(10)40, nogrid) graphregion(color(white)) bcolor(navy) saving(OA_Fig6b, replace)

graph export "OA_Fig6b.pdf", replace 
graph export "OA_Fig6b.eps", replace


gen perc_allcorrect = all_correct*100

gen all_payment = 0
replace all_payment = 1 if taskpayment == 10


replace menutype = . if menutype == 7 | menutype == 9 | menutype == 10 | menutype == 11 | menutype==13 
replace alt_ranking2 = . if alt_ranking2 ==3 | alt_ranking2== 7 | alt_ranking2== 9 | alt_ranking2== 10 | alt_ranking2== 11 | alt_ranking2==12 

// OA-C.2 FIGURE 7(a) 

graph bar (mean) perc_allcorrect, over(menutype, relabel(1 "{it:{stSerif:GUILT}}" 2 "{it:{stSerif:SSB_{subscript:0}}}" 3 "{it:{stSerif:SSB_{subscript:1}}}" 4 "{it:{stSerif:FLEX_{subscript:0}}}" 5 "{it:{stSerif:FLEX_{subscript:1}}}" 6 "{it:{stSerif:STD_{subscript:0}}}" 7 "{it:{stSerif:FLEX_{subscript:0v1}}}" )) ytitle("""") yvaroptions(relabel(1 "proportion of subjects with perfect score by menu type")) title("Classification based on rank ordering") blabel(bar, position(outside) format(%9.1f))  ylab(0(20)60, nogrid) graphregion(color(white)) saving(g1, replace) nodraw
graph bar (mean) perc_allcorrect, over(alt_ranking2, relabel(1 "{it:{stSerif:GUILT}}" 2 "{it:{stSerif:SSB_{subscript:0}}}" 3 "{it:{stSerif:SSB_{subscript:1}}}" 4 "{it:{stSerif:FLEX_{subscript:0}}}" 5 "{it:{stSerif:FLEX_{subscript:1}}}" 6 "{it:{stSerif:STD_{subscript:0}}}" 7 "{it:{stSerif:IND}}" )) ytitle("""") yvaroptions(relabel(1 "proportion of subjects with perfect score by menu type")) title("Classification based on {it:{stSerif:WTP}}") blabel(bar, position(outside) format(%9.1f))  ylab(0(20)60, nogrid) graphregion(color(white)) saving(g2, replace) nodraw
graph combine g1.gph g2.gph, col(1) graphregion(color(white)) saving(OA_Fig7a, replace)

graph export "OA_Fig7a.pdf", replace 
graph export "OA_Fig7a.eps", replace

// OA-C.2 FIGURE 7(b) 

graph bar (mean) taskpayment, over(menutype, relabel(1 "{it:{stSerif:GUILT}}" 2 "{it:{stSerif:SSB_{subscript:0}}}" 3 "{it:{stSerif:SSB_{subscript:1}}}" 4 "{it:{stSerif:FLEX_{subscript:0}}}" 5 "{it:{stSerif:FLEX_{subscript:1}}}" 6 "{it:{stSerif:STD_{subscript:0}}}" 7 "{it:{stSerif:FLEX_{subscript:0v1}}}" )) ytitle("""") yvaroptions(relabel(1 "average earnings in $ from the attention task by menu type")) title("Classification based on rank ordering") ylab(0(2)10, nogrid)  graphregion(color(white)) blabel(bar, position(outside) format(%9.1f)) saving(g1, replace) nodraw
graph bar (mean) taskpayment, over(alt_ranking2, relabel(1 "{it:{stSerif:GUILT}}" 2 "{it:{stSerif:SSB_{subscript:0}}}" 3 "{it:{stSerif:SSB_{subscript:1}}}" 4 "{it:{stSerif:FLEX_{subscript:0}}}" 5 "{it:{stSerif:FLEX_{subscript:1}}}" 6 "{it:{stSerif:STD_{subscript:0}}}" 7 "{it:{stSerif:IND}}" )) ytitle("""") yvaroptions(relabel(1 "  average earnings from the attention task by menu type")) title("Classification based on {it:{stSerif:WTP}}") ylab(0(2)10, nogrid) graphregion(color(white)) blabel(bar, position(outside) format(%9.1f)) saving(g2, replace) nodraw
graph combine g1.gph g2.gph, col(1) graphregion(color(white)) saving(OA_Fig7b, replace)

graph export "OA_Fig7b.pdf", replace 
graph export "OA_Fig7b.eps", replace


***************************
// OA-H: POWER CALCULATIONS
***************************

// OA-H.1 Menu Preferences - Binomial Test - Figure 24

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox /*current directory*/
insheet using "/Users/severinetoussaert/stoussaert/Dropbox/curiosity/power_menu_2sided.csv", clear // Data generated using G*Power 3.1 (see OA-H)

twoway scatter beta_001 p if p<=0.4, connect(ascending) xtitle("proportion {it:{stSerif:p}}") ytitle("power curve {&beta}({it:{stSerif:p}})") msymbol(i) ylabel(0(0.2)1) xlabel(0(0.1)0.4) legend(label(1 "{it:{&alpha}} {&le} 0.001")) || ///
scatter beta_01 p if p<=0.4, connect(ascending) ytitle("power curve {&beta}({it:{stSerif:p}})") msymbol(i) ylabel(0(0.2)1) xlabel(0(0.1)0.4) legend(label(2 "{it:{&alpha}} {&le} 0.01")) || ///
scatter beta_05 p if p<=0.4, connect(ascending) ytitle("power curve {&beta}({it:{stSerif:p}})") msymbol(i) ylabel(0(0.2)1) xlabel(0(0.1)0.4) legend(label(3 "{it:{&alpha}} {&le} 0.05")) || ///
scatter beta_10 p if p<=0.4, connect(ascending) ytitle("power curve {&beta}({it:{stSerif:p}})") msymbol(i) ylabel(0(0.2)1) xlabel(0(0.1)0.4) legend(label(4 "{it:{&alpha}} {&le} 0.10") ///
col(4)) graphregion(color(white)) saving(OA_Fig24, replace)

graph export "OA_Fig24.pdf", replace 
graph export "OA_Fig24.eps", replace


// OA-H.2 Auxiliary Data - Regression analysis - Figure 25

// Figure 25(a): Power as function of effect size for different values of alpha 

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox /*current directory*/
insheet using "/Users/severinetoussaert/stoussaert/Dropbox/curiosity/regression_posthoc.csv", clear // Data generated using G*Power 3.1 (see OA-H)

twoway scatter power2_001 effect_size if effect_size <=0.4, connect(ascending) xtitle("Cohen {it:{stSerif:f}} {sup:2}") ytitle("power curve {&beta}({it:{stSerif:f{sup:2}}})") msymbol(i) ylabel(0(0.2)1) xlabel(0(0.05)0.4) legend(label(1 "{it:{&alpha}} = 0.001")) || ///
scatter power2_01 effect_size if effect_size <=0.4, connect(ascending) ytitle("power curve {&beta}({it:{stSerif:f}} {sup:2})") msymbol(i) ylabel(0(0.2)1) xlabel(0(0.05)0.4) legend(label(2 "{it:{&alpha}} = 0.01")) || ///
scatter power2_05 effect_size if effect_size <=0.4, connect(ascending) ytitle("power curve {&beta}({it:{stSerif:f}} {sup:2})") msymbol(i) ylabel(0(0.2)1) xlabel(0(0.05)0.4) legend(label(3 "{it:{&alpha}} = 0.05")) || ///
scatter power2_1 effect_size if effect_size <=0.4, connect(ascending) ytitle("power curve {&beta}({it:{stSerif:f}} {sup:2})") msymbol(i) ylabel(0(0.2)1) xlabel(0(0.05)0.4) legend(label(4 "{it:{&alpha}} = 0.1") /// 
col(4)) graphregion(color(white)) saving(OA_Fig25a, replace)

graph export "OA_Fig25a.pdf", replace 
graph export "OA_Fig25a.eps", replace

// Figure 25(b): Sample size as function of effect size for different values of beta

clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox /*current directory*/
insheet using "/Users/severinetoussaert/stoussaert/Dropbox/curiosity/regression_power.csv", clear // Data generated using G*Power 3.1 (see OA-H)

twoway scatter n2_70 effect_size if effect_size <=0.15, connect(ascending) xtitle("Cohen {it:{stSerif:f}} {sup:2}") ytitle("required sample size") msymbol(i)  xlabel(0(0.01)0.15) legend(label(1 "{it:{&beta}} = 0.70")) || ///
scatter n2_80 effect_size if effect_size <=0.15, connect(ascending) msymbol(i) xlabel(0(0.01)0.15) legend(label(2 "{it:{&beta}} = 0.80")) || ///
scatter n2_90 effect_size if effect_size <=0.15, connect(ascending) msymbol(i)  xlabel(0(0.01)0.15) legend(label(3 "{it:{&beta}} = 0.90") ///
col(3)) graphregion(color(white)) saving(OA_Fig25b, replace)

graph export "OA_Fig25b.pdf", replace 
graph export "OA_Fig25b.eps", replace









