clear
set more off 
cd /Users/severinetoussaert/stoussaert/Dropbox/ECMA_revision/dataset/raw_data /*current directory*/
insheet using "raw_data_all.csv", clear


// PRODUCTIVITY VARIABLES

gen payment = taskpayment + beliefpayoff + showupfee - pay // Total earnings

gen total_correct = correctanswer1 + correctanswer2 + correctanswer3 + correctanswer4 + correctanswer5 + correctanswer6 // Number of correct answers in the attention task 

gen all_correct = 0
replace all_correct = 1 if total_correct ==5 // Dummy for perfect score


// WTP reshape

foreach i of numlist 1(1)8  {
			replace wtp1_choice`i' = . if wtp1_choice`i' == 1000
			replace wtp2_choice`i' = . if wtp2_choice`i' == 1000
			replace tc1_choice`i' = . if tc1_choice`i' == 1000
			replace tc2_choice`i' = . if tc2_choice`i' == 1000
						}
						
// Distribution of wtp in terms of time/money (number of rows at which the subject is willing to pay)

// $ WTP condition
gen wtp1_total = wtp1_choice1 + wtp1_choice2 + wtp1_choice3 + wtp1_choice4 + wtp1_choice5 + wtp1_choice6 + wtp1_choice7 + wtp1_choice8
gen wtp2_total = wtp2_choice1 + wtp2_choice2 + wtp2_choice3 + wtp2_choice4 + wtp2_choice5 + wtp2_choice6 + wtp2_choice7 + wtp2_choice8

// Time WTP condition
gen tc1_total = tc1_choice1 + tc1_choice2 + tc1_choice3 + tc1_choice4 + tc1_choice5 + tc1_choice6 + tc1_choice7 + tc1_choice8
gen tc2_total = tc2_choice1 + tc2_choice2 + tc2_choice3 + tc2_choice4 + tc2_choice5 + tc2_choice6 + tc2_choice7 + tc2_choice8


// Monetary or time equivalent of switching points

gen money1 = 0
replace money1 = 0.01 if wtp1_total == 1
replace money1 = 0.02 if wtp1_total == 2
replace money1 = 0.05 if wtp1_total == 3
replace money1 = 0.1 if wtp1_total == 4
replace money1 = 0.2 if wtp1_total == 5
replace money1 = 0.3 if wtp1_total == 6
replace money1 = 0.4 if wtp1_total == 7
replace money1 = 0.5 if wtp1_total == 8
replace money1 = . if wtp1_total == .


gen money2 = 0
replace money2 = 0.01 if wtp2_total == 1
replace money2 = 0.02 if wtp2_total == 2
replace money2 = 0.05 if wtp2_total == 3
replace money2 = 0.1 if wtp2_total == 4
replace money2 = 0.2 if wtp2_total == 5
replace money2 = 0.3 if wtp2_total == 6
replace money2 = 0.4 if wtp2_total == 7
replace money2 = 0.5 if wtp2_total == 8
replace money2 = . if wtp2_total == .


gen ptime1 = 0
replace ptime1 = 60 if tc1_total == 1
replace ptime1 = 120 if tc1_total == 2
replace ptime1 = 180 if tc1_total == 3
replace ptime1 = 240 if tc1_total == 4
replace ptime1 = 300 if tc1_total == 5
replace ptime1 = 360 if tc1_total == 6
replace ptime1 = 480 if tc1_total == 7
replace ptime1 = 600 if tc1_total == 8
replace ptime1 = . if tc1_total == .


gen ptime2 = 0
replace ptime2 = 60 if tc2_total == 1
replace ptime2 = 120 if tc2_total == 2
replace ptime2 = 180 if tc2_total == 3
replace ptime2 = 240 if tc2_total == 4
replace ptime2 = 300 if tc2_total == 5
replace ptime2 = 360 if tc2_total == 6
replace ptime2 = 480 if tc2_total == 7
replace ptime2 = 600 if tc2_total == 8
replace ptime2 = . if tc2_total == .


// Big Five and curiosity scales - reverse coding

gen ibf2 = bf2
replace ibf2 = 1 if bf2 ==5
replace ibf2 = 5 if bf2 ==1
replace ibf2 = 2 if bf2 ==4
replace ibf2 = 4 if bf2 ==2

gen ibf3 = bf3
replace ibf3 = 1 if bf3 ==5
replace ibf3 = 5 if bf3 ==1
replace ibf3 = 2 if bf3 ==4
replace ibf3 = 4 if bf3 ==2

gen ibf5 = bf5
replace ibf5 = 1 if bf5 ==5
replace ibf5 = 5 if bf5 ==1
replace ibf5 = 2 if bf5 ==4
replace ibf5 = 4 if bf5 ==2

gen ibf7 = bf7
replace ibf7 = 1 if bf7 ==5
replace ibf7 = 5 if bf7 ==1
replace ibf7 = 2 if bf7 ==4
replace ibf7 = 4 if bf7 ==2

gen ibf8 = bf8
replace ibf8 = 1 if bf8 ==5
replace ibf8 = 5 if bf8 ==1
replace ibf8 = 2 if bf8 ==4
replace ibf8 = 4 if bf8 ==2

gen ibf10 = bf10 
replace ibf10 = 1 if bf10 ==5
replace ibf10 = 5 if bf10 ==1
replace ibf10 = 2 if bf10 ==4
replace ibf10 = 4 if bf10 ==2

gen icd8 = cd8
replace icd8 = 1 if cd8 ==5
replace icd8 = 5 if cd8 ==1
replace icd8 = 2 if cd8 ==4
replace icd8 = 4 if cd8 ==2



// PREFERENCES

// A. Initial ranking

gen strict_12 = 0 // indicator for whether top strictly preferred to 2nd best
replace strict_12 = 1 if menutype <=6 | menutype ==10 | menutype==11 | menutype==12

gen strict_23 = 0 // indicator for whether 2nd best strictly preferred to last
replace strict_23 = 1 if menutype <=9

gen indiff1 = 0 // indicator for whether indifferent between top and 2nd best
replace indiff1 = 1 if menutype ==7 | menutype==8 | menutype==9 | menutype==13

gen indiff2 = 0 // indicator for whether indifferent between 2nd best and last
replace indiff2 = 1 if menutype ==10 | menutype==11 | menutype==12 | menutype==13


// B. WTP

gen strict_pref1 = 0  // Indicator for strict preference over top vs. 2nd best based on WTP
replace strict_pref1 = 1 if (wtp1_total > 0 & wtp1_total !=.) | (tc1_total >0 & tc1_total !=.)

gen strict_pref2 = 0 // Indicator for strict preference over 2nd best vs. top based on WTP
replace strict_pref2 = 1 if (wtp2_total > 0 & wtp2_total !=.) | (tc2_total >0 & tc2_total !=.) 


// Consistency between A. and B.

gen inconsistent1 = 0
replace inconsistent1 = 1 if strict_12 ==0 & strict_pref1==1 | strict_23 ==0 & strict_pref2==1

gen inconsistent2 = 0
replace inconsistent2 = 1 if (strict_12 != strict_pref1) | (strict_23 != strict_pref2)


// Alternative ranking #1: Replacing strict order when WTP = 0 and not taking into account indifferences with WTP>0 

gen alt_ranking1 = menutype 
replace alt_ranking1 = 13 if strict_pref1==0 & strict_pref2==0 
replace alt_ranking1 = 7 if (menutype==1 | menutype==3) & strict_pref1==0 & strict_pref2==1
replace alt_ranking1 = 8 if (menutype==2 | menutype==5) & strict_pref1==0 & strict_pref2==1
replace alt_ranking1 = 9 if (menutype==4 | menutype ==6) & strict_pref1==0 & strict_pref2==1
replace alt_ranking1 = 10 if (menutype==1 | menutype==2) & strict_pref1==1 & strict_pref2==0
replace alt_ranking1 = 11 if (menutype==3 | menutype==4) & strict_pref1==1 & strict_pref2==0
replace alt_ranking1 = 12 if (menutype==5 | menutype == 6) & strict_pref1==1 & strict_pref2==0


// Alternative ranking #2: Replacing indifferences with WTP>0 by strict pref (Table 3 main text)
	
gen alt_ranking2 = alt_ranking1 
replace alt_ranking2 = 1 if menutype==7 & strict_pref1==1 & strict_pref2==1
replace alt_ranking2 = 2 if menutype==8 & strict_pref1==1 & strict_pref2==1
replace alt_ranking2 = 1 if menutype==10 & strict_pref1==1 & strict_pref2==1
replace alt_ranking2 = 3 if menutype==11 & strict_pref1==1 & strict_pref2==1
replace alt_ranking2 = 5 if menutype==12 & strict_pref1==1 & strict_pref2==1
replace alt_ranking2 = 8 if menutype==12 & strict_pref1==0 & strict_pref2==1
replace alt_ranking2 = 4 if menutype==9 & strict_pref1==1 & strict_pref2==1

gen sum_ranks = menuchoice1 + menuchoice2 + menuchoice3



gen pref_0 = 0 // {0} > {1} according to initial ranking
replace pref_0 = 1 if menutype ==1 | menutype ==2 | menutype == 5 | menutype ==8 | menutype == 10

gen pref_1 = 0 // {1} > {0} according to initial ranking
replace pref_1 = 1 if menutype ==3 | menutype ==4 | menutype == 6 | menutype ==9 | menutype == 11

gen pref_sim = 0 // {0} = {1} according to initial ranking
replace pref_sim = 1 if menutype ==7 | menutype == 12 | menutype ==13 


gen strict_pref0 = 0
replace strict_pref0 = 1 if pref_0==1
replace strict_pref0 = . if pref_sim==1


gen pref_0_alt = 0 // {0} > {1} according to classification based on WTP
replace pref_0_alt = 1 if alt_ranking2 ==1 | alt_ranking2 ==2 | alt_ranking2 == 5 | alt_ranking2 ==8 | alt_ranking2 == 10

gen pref_1_alt = 0 // {1} > {0} according to classification based on WTP
replace pref_1_alt = 1 if alt_ranking2 ==3 | alt_ranking2 ==4 | alt_ranking2 == 6 | alt_ranking2 ==9 | alt_ranking2 == 11

gen pref_sim_alt = 0 // {0} = {1} according to classification based on WTP
replace pref_sim_alt = 1 if alt_ranking2 ==7 | alt_ranking2 == 12 | alt_ranking2 ==13 


gen strict_pref0_alt = 0
replace strict_pref0_alt = 1 if pref_0_alt==1
replace strict_pref0_alt = . if pref_sim_alt==1


// COMPUTATION OF THE ODDS OF FACING EACH MENU

gen total_wtp1 = wtp1_choice1 + wtp1_choice2 + wtp1_choice3 + wtp1_choice4 + wtp1_choice5 + wtp1_choice6 + wtp1_choice7 + wtp1_choice8 
replace total_wtp1 = tc1_choice1 + tc1_choice2 + tc1_choice3 + tc1_choice4 + tc1_choice5 + tc1_choice6 + tc1_choice7 + tc1_choice8 if dietypewtp ==2

gen total_wtp2 = wtp2_choice1 + wtp2_choice2 + wtp2_choice3 + wtp2_choice4 + wtp2_choice5 + wtp2_choice6 + wtp2_choice7 + wtp2_choice8 
replace total_wtp2 = tc2_choice1 + tc2_choice2 + tc2_choice3 + tc2_choice4 + tc2_choice5 + tc2_choice6 + tc2_choice7 + tc2_choice8 if dietypewtp ==2

gen p1 = total_wtp1/8 // Likelihood of replacement conditional on 2nd choice being chosen
gen p2 = total_wtp2/8 // Likelihood of replacement conditional on last choice being chosen

gen p_top = 0.5 if menutype <=6 | menutype ==10 | menutype==11 | menutype ==12 
replace p_top = 0.4 if menutype ==7 | menutype==8 | menutype ==9
replace p_top = 1/3 if menutype ==13

gen p_second = 0.3 if menutype <=6 
replace p_second = 0.4 if menutype ==7 | menutype==8 | menutype ==9 // second has rank 1 
replace p_second = 0.25 if menutype ==10 | menutype==11 | menutype ==12 // second is last 
replace p_second = 1/3 if menutype ==13

gen p_last = 0.2 if menutype <=9
replace p_last = 0.25 if menutype ==10 | menutype==11 | menutype ==12
replace p_last = 1/3 if menutype==13

gen p_total = p_top + p_second + p_last 

gen flex_top = 0
replace flex_top = 1 if topchoice == 3

gen flex_second = 0
replace flex_second = 1 if secondchoice==3

gen flex_last = 0
replace flex_last = 1 if lastchoice==3


gen odds_top = 0.5*flex_top + 0.5*p_top + 0.5*p_second*p1

gen odds_second = 0.5*flex_second + 0.5*p_second*(1-p1) + 0.5*p_last*p2

gen odds_last = 0.5*flex_last + 0.5*p_last*(1-p2)

gen total_odds = odds_top + odds_second + odds_last 


gen odds_0 = odds_top if topchoice==1 
replace odds_0 = odds_second if secondchoice==1
replace odds_0 = odds_last if lastchoice==1

gen odds_1 = odds_top if topchoice==2
replace odds_1 = odds_second if secondchoice==2
replace odds_1 = odds_last if lastchoice==2

gen odds_01 = odds_top if topchoice==3
replace odds_01 = odds_second if secondchoice==3
replace odds_01 = odds_last if lastchoice==3

gen total_menu_odds = odds_0 + odds_1 + odds_01


outsheet using data_reshaped.xls, replace

